@@ -11,7 +11,7 @@ progress.add_column("x root", color=Fore.RED)
 for step in range(20):
     progress["step"] = step
 
-    for _ in progress(range(10)):
+    for _ in progress(range(10), length=5):
         time.sleep(0.1)  # artificial work
 
     x = random.randint(0, 200)
